# TOPSIS_Harsh_101917088
## What is TOPSIS?

Technique for Order Preference by Similarity to Ideal Solution (TOPSIS) originated in the 1980s as a multi-criteria decision making method. TOPSIS chooses the alternative of shortest Euclidean distance from the ideal solution, and greatest distance from the negative-ideal solution.


## Installation 
How to use this package?
First you have to install the package name 'Topsis-Harsh-101917088' using the following command:

'''pip install TOPSIS_Harsh_101917088'''

{If it doesn't work use version after above command}

## How to use it?
Open terminal and type PYTHON TOPSIS along with input file path whose topsis value and rank you wanted to find
i.e python TOPSIS "data.csv" 


##Arguments Required:
(Assumne we have 3 attributes in dataset.)
You have to required one .csv file. (101917118-data.csv)
Pass weights to each attribute. (e.g.: [1,1,1])
Pass impacts to each attribute. (e.g.: [+,-,+])
Pass the name of the file with you want to put on .csv file. (101917118-result.csv)


Give arguments like
Example
python 101556.py 101556-data.csv “1,1,1,2” “+,+,-,+” 101556-result.csv

Please make sure to update tests as appropriate.

##Github Link
https://github.com/Harsh23Kashyap/Predictive-Analysis/tree/main/Assignment4%20-%20Topsis/Solution 


##Happy Coding!!!
